@@ -17,6 +17,10 @@ class CopyFeature(Feature):
     def name(self) -> str:
         return "copy"
 
+    @property
+    def dependencies(self) -> Iterable[str]:
+        return ["core"]
+
     @property
     def schema(self) -> ClassVar[FeatureSchema]:
         return CopySchema
