@@ -16,6 +16,10 @@ class GitFeature(Feature):
     def name(self) -> str:
         return "git"
 
+    @property
+    def dependencies(self) -> Iterable[str]:
+        return ["core"]
+
     @property
     def schema(self) -> ClassVar[GitSchema]:
         return GitSchema
