@@ -1,11 +1,16 @@
 import os
 import shutil
 
+import pytest
+
 from _pytest.capture import CaptureFixture
 from compose.config.types import ServicePort
+from dotty_dict import Dotty
+
 from ddb.__main__ import load_registered_features, register_actions_in_event_bus
 from ddb.action import actions
 from ddb.binary import binaries
+from ddb.binary.binary import DefaultBinary
 from ddb.config import config
 from ddb.event import bus
 from ddb.feature import features
@@ -13,9 +18,10 @@ from ddb.feature.certs import CertsFeature
 from ddb.feature.core import CoreFeature
 from ddb.feature.docker import DockerDisplayInfoAction
 from ddb.feature.docker import DockerFeature, EmitDockerComposeConfigAction
+from ddb.feature.docker.binaries import DockerBinary
+from ddb.feature.docker.utils import get_mapped_path
 from ddb.feature.traefik import TraefikFeature
 from ddb.utils.process import effective_command
-from dotty_dict import Dotty
 from tests.utilstest import setup_cfssl
 
 
@@ -164,7 +170,9 @@ class TestDockerFeature:
         assert binaries.has("npm-conditions")
         assert binaries.has("mysql")
 
-        npm_simple = binaries.get("npm-simple")
+        npm_simple_set = binaries.get("npm-simple")
+        assert len(npm_simple_set) == 1
+        npm_simple = list(npm_simple_set)[0]
         assert npm_simple.command() == (''.join(
             effective_command(
                 "docker-compose")) + " run --rm --workdir=/app/. --label traefik.enable=false node").split()
@@ -175,7 +183,9 @@ class TestDockerFeature:
             effective_command(
                 "docker-compose")) + ' run --rm --workdir=/app/. --label traefik.enable=false node').split()
 
-        npm_conditions = binaries.get("npm-conditions")
+        npm_conditions_set = binaries.get("npm-conditions")
+        assert len(npm_conditions_set) == 1
+        npm_conditions = list(npm_conditions_set)[0]
         assert npm_conditions.command() == (''.join(
             effective_command(
                 "docker-compose")) + " run --rm --workdir=/app/. --label traefik.enable=false node").split()
@@ -185,7 +195,9 @@ class TestDockerFeature:
         assert npm_conditions.command("run serve") == (
                 ''.join(effective_command("docker-compose")) + ' run --rm --workdir=/app/. node').split()
 
-        mysql = binaries.get("mysql")
+        mysql_set = binaries.get("mysql")
+        assert len(mysql_set) == 1
+        mysql = list(mysql_set)[0]
         assert mysql.command() == (''.join(effective_command(
             "docker-compose")) + ' run --rm --workdir=/app/. db mysql -hdb -uproject-management-tool -pproject-management-tool').split()
 
@@ -224,6 +236,7 @@ class TestDockerFeature:
         assert os.path.isdir('child')
         assert os.path.isdir(os.path.join('new_directory', 'some', 'child'))
 
+    @pytest.mark.docker
     def test_traefik_cert(self, project_loader, module_scoped_container_getter):
         project_loader("traefik-cert")
 
@@ -279,7 +292,6 @@ class TestDockerFeature:
         assert os.path.exists(os.path.join(config.paths.home, "certs", "web-changed.domain.tld.crt"))
         assert os.path.exists(os.path.join(config.paths.home, "traefik", "config", "web-changed.domain.tld.ssl.toml"))
 
-
 class TestDockerDisplayInfoAction:
 
     def test_retrieve_environment_data(self):
@@ -353,7 +365,7 @@ class TestDockerDisplayInfoAction:
 
         config.args.type = None
 
-        assert '' == action._output_data('test', list(), [], [], [])
+        assert '' == action._output_data('test', dict(), [], [], [])
 
         test_vhosts = action._retrieve_vhosts_data(Dotty({'labels': {
             'traefik.http.routers.defaults-project.rule': 'Host(`web.domain.tld`)',
@@ -367,7 +379,7 @@ class TestDockerDisplayInfoAction:
                            '+-------------------------+',
                            '| http://test.tld/        |',
                            '| https://web.domain.tld/ |',
-                           '+-------------------------+'])) == action._output_data('test', list(), [],
+                           '+-------------------------+'])) == action._output_data('test', dict(), [],
                                                                                    [], test_vhosts)
 
         test_binaries = action._retrieve_binaries_data(Dotty({'labels': {
@@ -384,7 +396,7 @@ class TestDockerDisplayInfoAction:
                            '+-------------------------+',
                            '| http://test.tld/        |',
                            '| https://web.domain.tld/ |',
-                           '+-------------------------+'])) == action._output_data('test', list(), [],
+                           '+-------------------------+'])) == action._output_data('test', dict(), [],
                                                                                    test_binaries, test_vhosts)
 
         test_envs = action._retrieve_environment_data(Dotty({'environment': {'AZERTY': '123'}}))
@@ -418,7 +430,7 @@ class TestDockerDisplayInfoAction:
                                                                                    test_binaries, test_vhosts)
 
         config.args.type = 'nothing'
-        assert '' == action._output_data('test', list(), [], [], test_vhosts)
+        assert '' == action._output_data('test', dict(), [], [], test_vhosts)
 
         config.args.type = 'vhost'
         assert ('\n'.join(['+-------------------------+',
@@ -426,7 +438,7 @@ class TestDockerDisplayInfoAction:
                            '+-------------------------+',
                            '| http://test.tld/        |',
                            '| https://web.domain.tld/ |',
-                           '+-------------------------+'])) == action._output_data('test', list(), [],
+                           '+-------------------------+'])) == action._output_data('test', dict(), [],
                                                                                    [], test_vhosts)
 
     def test_execute_traefik_cert(self, capsys: CaptureFixture, project_loader):
@@ -473,3 +485,51 @@ class TestDockerDisplayInfoAction:
                            '| https://sub.test --> http://192.168.99.1:8080 |',
                            '+-----------------------------------------------+',
                            '\n'])) == capture.out
+
+
+class TestDockerBinary:
+    def test_docker_binary_compare_ne(self):
+        binary1 = DockerBinary("npm", "node1")
+        binary2 = DockerBinary("npm", "node2")
+        binary3 = DockerBinary("npm", "node3")
+        binary4 = DockerBinary("npm", "node4")
+
+        assert binary1 != binary2 != binary3 != binary4
+        assert hash(binary1) != hash(binary2) != hash(binary3) != hash(binary4)
+
+    def test_docker_binary_compare_eq(self):
+        binary1 = DockerBinary("npm", "node")
+        binary2 = DockerBinary("npm", "node")
+
+        assert binary1 == binary2
+        assert hash(binary1) == hash(binary2)
+
+    def test_docker_binary_sort(self):
+        binary1 = DockerBinary("npm", "node1")
+        binary2 = DockerBinary("npm", "node2")
+        binary3 = DefaultBinary("npm", ["npm"])
+        binary4 = DockerBinary("npm", "node4")
+
+        bins = (binary1, binary2, binary3, binary4)
+        sorted_bins = tuple(sorted(bins))
+        expected = (binary1, binary2, binary4, binary3)
+
+        assert sorted_bins == expected
+
+        binary_with_condition = DockerBinary("npm", "node5", condition="some-condition")
+
+        bins = (binary1, binary2, binary_with_condition, binary3, binary4)
+        sorted_bins = tuple(sorted(bins))
+        expected = (binary_with_condition, binary1, binary2, binary4, binary3)
+
+        assert sorted_bins == expected
+
+    def test_docker_utils_get_mapped_path(self):
+        assert get_mapped_path('/home/toilal/projects/test') == '/home/toilal/projects/test'
+
+        config.data['docker.path_mapping'] = {
+            '/home/toilal/projects': '/projects',
+            '/home/toilal': '/home'
+        }
+
+        assert get_mapped_path('/home/toilal/projects/test') == '/projects/test'
